#!/bin/bash

### COPYRIGHT NOTICE ###
# Copyright (C) 2006-2009 TOLIS Group, Inc. All rights reserved.

### DISCLAIMER ###
# TOLIS provides this script and assumes no responsibility
# for the content or operation in any particular environment.
# Further, TOLIS assumes no liability for potential harm or
# damage, software or hardware, that may result from the use of
# this script. The script are provided as-is only and may be
# modified for your use. VERIFY THE USEFULNESS of the script
# before you use it. The downloading and use of this script
# indicates that you have read and agree to these terms.

### ABOUT THIS SCRIPT ###
# This script will assist in finding the gdbm DB file(s) that are corrupt
# and causing a "gdbm fatal read error" when trying to start BRU Server.
# DO NOT RUN THIS SCRIPT MORE THAN ONCE! Doing so may cause good DB files
# to become erased. It is strongly advised that you backup your BRU Server
# Environment before troubleshooting the corrupt DB file.

#################################################
# Do not change anything below unless you know #
# what you are doing! #
#################################################

ROOT_UID=0
E_XCD=66
E_NOTROOT=67
SERVERDIR="/usr/local/bru-server"
FULLDIR_MAC="/Applications/BRU Server Config Tool.app/Contents/MacOS"

# Check if running as Root.
if [ "$UID" -ne "$ROOT_UID" ]; then
printf "\tMust be root (sudo) to run this script.\n"
printf "\tTry running this script with the 'sudo' command.\n"
exit $E_NOTROOT
fi

cd $SERVERDIR
if [ `pwd` != "$SERVERDIR" ]; then
    printf "\tCannot change to $SERVERDIR.\n"
    printf "\tTrying Mac OS X path...\n"
    cd $FULLDIR_MAC
    if [ `pwd` != "$FULLDIR_MAC" ]; then
        printf "\tCannot change to $FULLDIR_MAC.\n"
        printf "\tBRU Server install path cannot be found. Please check your installation\n"
        printf "\tand make sure that this script is being run on the BRU Server Server system.\n"
        printf "\n\tExiting script.\n"
        exit $E_XCD
    fi
fi

FILES1="archives backup dest devices drives history license"
FILES2="machines parm schedule tapes upstage user"

for DB in $FILES1 $FILES2
    do
        if [ ! -e "$DB.save" ]; then
            mv $DB $DB.save
        else
            printf "\nThere is already a \"$DB.save\" file in the BRU Server directory.\n"
            printf "Continuing with this script may erase good DB files.\n"
            printf "Do you want to move the \"$DB.save\" file first? [N/y] "
            read ANSWER
            if [ "$ANSWER" = "Y" -o "$ANSWER" = "y" ]; then
                if [ ! -e "$DB.copy" ]; then
                    mv $DB.save $DB.copy
                else
                    printf "\n\n==============================================================\n"
                    printf "UNABLE TO MOVE FILE!\n"
                    printf "There is already a \"$DB.save\" and \"$DB.copy\" DB file in the\n"
                    printf "BRU Server main directory. No modifications have been made to your\n"
                    printf "system at this time.\n"
                    printf "Please contact TOLIS Group Support for further assistance at\n"
                    printf "http://support.tolisgroup.com or 480-505-1814.\n"
                    printf "\nExiting script."
                    printf "\n==============================================================\n\n"
                    exit 1
                fi
            else
                printf "\nNo modifications have been made to your system.\n"
                printf "Please move the \".save\" DB files to a safe location before\n"
                printf "running this script again.\n\n"
                printf "Exiting script now!\n"
                exit 1
            fi
        fi
    done

for DB in $FILES1 $FILES2
    do
        printf "\nTesting $DB database table file...\n"
        printf "If BRU Server starts correctly, press CTRL-C to move to the next file\n"
        printf "when you see BRU Server start successfully.  This is usually indicated\n"
        printf "by a \"Bound socket\" message."
        sleep 2
        cp -f $DB.save $DB
        ./server --foreground
        if [ "$?" -ne "0" ]; then
            echo -ne "\a\nThe $DB file is corrupt - deleting...\n\n"
            rm $DB
        fi
    done

printf "\n\aBRU Server gdbm Database Fix Complete!\n\n"
sleep 2

exit 0

### EOF ###
